@@ -4,7 +4,7 @@ use warnings;
 use Syntax::Keyword::RawQuote ();
 
 BEGIN {
-  our $VERSION = '0.03';
+  our $VERSION = '0.04';
   our $AUTHORITY = 'cpan:ARODLAND';
 }
 
@@ -31,7 +31,7 @@ Syntax::Feature::RawQuote - A raw quote operator for Perl ('use syntax' flavor)
     say r`I keep all of my files in \\yourserver\private`;
 
     use syntax raw_quote => { -as => "qraw" };
-    say qraw[Maybe the \r\ keyword is too risky?];
+    say qraw[Maybe the `r` keyword is too risky?];
 
 =head1 DESCRIPTION
 
